@@ -40,8 +40,11 @@ OC.L10N.register(
     "Explore" : "Esplorar",
     "Settings" : "Configuración",
     "Keyboard shortcuts" : "Atayos del tecláu",
-    "Compact view" : "Vista compauta",
     "Show all articles" : "Amosar tolos artículos",
+    "Default" : "Por defeutu",
+    "Vertical" : "Vertical",
+    "Horizontal" : "Horizontal",
+    "Off" : "Non",
     "Rename Folder" : "Renomar la carpeta",
     "Rename" : "Renomar",
     "Delete" : "Desaniciar",
@@ -67,6 +70,8 @@ OC.L10N.register(
     "{num} days ago" : "hai {num} díes",
     "{num} months ago" : "hai {num} meses",
     "{num} years ago" : "hai {num} años",
+    "Title" : "Títulu",
+    "Not available" : "Nun ta disponible",
     "Keyboard shortcut" : "Atayos del tecláu",
     "Action" : "Aición",
     "Refresh" : "Anovar",
@@ -94,6 +99,7 @@ OC.L10N.register(
     "Open feed URL" : "Abrir l'URL del feed",
     "Dismiss" : "Escartar",
     "Collapse" : "Recoyer",
+    "Compact view" : "Vista compauta",
     "Subscriptions (OPML)" : "Soscripciones (OPML)",
     "Import" : "Importar",
     "Export" : "Esportar",
