@@ -9,10 +9,13 @@ OC.L10N.register(
     "Move" : "Senkez",
     "Share" : "Bḍu",
     "Settings" : "Iɣewwaṛen",
+    "Default" : "Prédéfini(e)",
+    "Off" : "Ur irmid ara",
     "Rename" : "Beddel isem",
     "Delete" : "Kkes",
     "Newest first" : "Imaynuten d imezwura",
     "Oldest first" : "Iqbuṛen d imezwura",
+    "Title" : "Azwel",
     "Refresh" : "Sismeḍ",
     "Create" : "Snulfu-d",
     "Dismiss" : "Agi",
