@@ -29,9 +29,9 @@ OC.L10N.register(
     "Settings" : "Paramètres",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Disable mark read through scrolling" : "Marcar pas los articles coma legits al moment del percors de las listas",
-    "Compact view" : "Vista compacta",
     "Show all articles" : "Afichar totes los articles",
     "Reverse ordering (oldest on top)" : "Òrdre invèrse (los mai ancians amont)",
+    "Off" : "Atudat",
     "Rename Folder" : "Renomenar lo dossièr",
     "Rename" : "Renomenar",
     "Delete" : "Suprimir",
@@ -46,11 +46,12 @@ OC.L10N.register(
     "Keep article unread" : "Marcar l'article coma pas legit",
     "Toggle keep current article unread" : "Marcar l'article coma Legit / Non legit",
     "Remove keep article unread" : "Marcar l'article coma legit",
+    "Title" : "Títol",
     "Keyboard shortcut" : "Acorchis de clavièr",
-    "right" : "droite",
     "Jump to next article" : "Anar al prochain article",
-    "left" : "gauche",
     "Jump to previous article" : "Anar a l'article precedent",
+    "right" : "droite",
+    "left" : "gauche",
     "Star article and jump to next one" : "Espingolar l'article e anar al seguent",
     "Open article in new tab" : "Dobrir l'article dins un nouvel onglet",
     "Refresh" : "Refrescar",
@@ -78,6 +79,7 @@ OC.L10N.register(
     "Collapse" : "Replegar",
     "Deleted folder" : "Dorsièr suprimit",
     "Undo delete folder" : "Anullar la supression del dorsièr",
+    "Compact view" : "Vista compacta",
     "Expand articles on key navigation" : "Espandir los articles al moment de la navigacion amb lo clavièr",
     "Subscriptions (OPML)" : "Abonaments (OPML)",
     "Import" : "Importar",
